@@ -1,25 +1,8 @@
 //
 // Copyright 2019 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_IMAGING_HD_ST_PRIM_UTILS_H
 #define PXR_IMAGING_HD_ST_PRIM_UTILS_H
@@ -122,8 +105,9 @@ void HdStSetMaterialTag(HdSceneDelegate *delegate,
                         HdRenderParam *renderParam,
                         HdDrawItem *drawItem,
                         SdfPath const & materialId,
-                        bool hasDisplayOpacityPrimvar,
-                        bool occludedSelectionShowsThrough);
+                        const bool hasDisplayOpacityPrimvar,
+                        const bool displayInOverlay,
+                        const bool occludedSelectionShowsThrough);
 // Resolves the material network shader for the given prim (using a fallback
 // material as necessary).
 HDST_API
@@ -182,6 +166,21 @@ HdStGetRemovedPrimvarBufferSpecs(
     TfTokenVector const& internallyGeneratedPrimvarNames,
     SdfPath const& rprimId);
 
+// Returns the buffer specs that have been removed from curRange based on the
+// new primvar descriptors, updated specs and internally generated primvar names. Buffer
+// specs with updated types will be replaced.
+// This overload handles primvar type changes and should be preferred over 
+// HdStGetRemovedPrimvarBufferSpecs.
+//
+HDST_API
+HdBufferSpecVector
+HdStGetRemovedOrReplacedPrimvarBufferSpecs(
+    HdBufferArrayRangeSharedPtr const& curRange,
+    HdPrimvarDescriptorVector const& newPrimvarDescs,
+    TfTokenVector const& internallyGeneratedPrimvarNames,
+    HdBufferSpecVector const& updatedSpecs,
+    SdfPath const& rprimId);
+
 // Updates the existing range at drawCoordIndex with newRange and flags garbage
 // collection (for the existing range) and rebuild of all draw batches when
 // necessary.
