@@ -119,12 +119,13 @@ public:
     SDF_API
     void ClearDisplayUnit();
 
-    /// Returns the color-space in which a color or texture valued attribute 
-    /// is authored.
+    /// Returns the color space in which a color or texture valued attribute 
+    /// is authored. Refer to GfColorSpaceNames for the list of built in
+    /// color spaces.
     SDF_API
     TfToken GetColorSpace() const;
 
-    /// Sets the color-space in which a color or texture valued attribute is 
+    /// Sets the color space in which a color or texture valued attribute is 
     /// authored.
     SDF_API
     void SetColorSpace(const TfToken &colorSpace);
@@ -207,6 +208,26 @@ public:
     /// @}
 };
 
+/// Convenience function to create an attributeSpec on a primSpec at the given
+/// path, and any necessary parent primSpecs, in the given layer.
+///
+/// If an attributeSpec already exists at the given path,
+/// author typeName, variability, and custom according to passed arguments
+/// and return an attribute spec handle.
+///
+/// Any newly created prim specs have SdfSpecifierOver and an empty type (as if
+/// created by SdfJustCreatePrimInLayer()).  attrPath must be a valid prim
+/// property path (see SdfPath::IsPrimPropertyPath()).  Return false and issue
+/// an error if we fail to author the required scene description.
+SDF_API
+SdfAttributeSpecHandle
+SdfCreatePrimAttributeInLayer(
+    const SdfLayerHandle &layer,
+    const SdfPath &attrPath,
+    const SdfValueTypeName &typeName,
+    SdfVariability variability = SdfVariabilityVarying,
+    bool isCustom = false);
+
 /// Convenience function to create an attributeSpec on a primSpec at the given
 /// path, and any necessary parent primSpecs, in the given layer.
 ///
@@ -217,6 +238,9 @@ public:
 /// created by SdfJustCreatePrimInLayer()).  attrPath must be a valid prim
 /// property path (see SdfPath::IsPrimPropertyPath()).  Return false and issue
 /// an error if we fail to author the required scene description.
+///
+/// Differs only from SdfCreatePrimAttributeInLayer only in that a bool, not
+/// a handle, is returned.
 SDF_API
 bool
 SdfJustCreatePrimAttributeInLayer(
