@@ -1,25 +1,8 @@
 //
 // Copyright 2016 Pixar
 //
-// Licensed under the Apache License, Version 2.0 (the "Apache License")
-// with the following modification; you may not use this file except in
-// compliance with the Apache License and the following modification to it:
-// Section 6. Trademarks. is deleted and replaced with:
-//
-// 6. Trademarks. This License does not grant permission to use the trade
-//    names, trademarks, service marks, or product names of the Licensor
-//    and its affiliates, except as required to comply with Section 4(c) of
-//    the License and to reproduce the content of the NOTICE file.
-//
-// You may obtain a copy of the Apache License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the Apache License with the above modification is
-// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied. See the Apache License for the specific
-// language governing permissions and limitations under the Apache License.
+// Licensed under the terms set forth in the LICENSE.txt file available at
+// https://openusd.org/license.
 //
 #ifndef PXR_USD_SDF_TYPES_H
 #define PXR_USD_SDF_TYPES_H
@@ -39,6 +22,7 @@
 
 #include "pxr/base/arch/demangle.h"
 #include "pxr/base/arch/inttypes.h"
+#include "pxr/base/arch/pragmas.h"
 #include "pxr/base/gf/half.h"
 #include "pxr/base/gf/matrix2d.h"
 #include "pxr/base/gf/matrix3d.h"
@@ -259,7 +243,13 @@ enum _SDF_UNITSLIST_ENUM(elem) {                         \
 #define _SDF_FOR_EACH_UNITS(macro, args)                 \
     _SDF_FOR_EACH_UNITS_IMPL(macro, TF_PP_EAT_PARENS(args))
 
+// On Windows this call to _SDF_FOR_EACH_UNITS generates a C4003 warning.
+// This is harmless, but we disable the warning here so that external
+// projects that include this header don't run into it as well.
+ARCH_PRAGMA_PUSH
+ARCH_PRAGMA_MACRO_TOO_FEW_ARGUMENTS
 _SDF_FOR_EACH_UNITS(_SDF_DECLARE_UNIT_ENUM, _SDF_UNITS)
+ARCH_PRAGMA_POP
 
 /// A map of mapper parameter names to parameter values.
 typedef std::map<std::string, VtValue> SdfMapperParametersMap;
@@ -276,6 +266,13 @@ typedef std::map<std::string, std::vector<std::string> > SdfVariantsMap;
 //        the Compare template parameter.
 typedef std::map<SdfPath, SdfPath> SdfRelocatesMap;
 
+/// A single relocate specifying a source SdfPath and a target SdfPath for a 
+/// relocation.
+typedef std::pair<SdfPath, SdfPath> SdfRelocate;
+
+/// A vector of relocation source path to target path pairs.
+typedef std::vector<SdfRelocate> SdfRelocates;
+
 /// A map from sample times to sample values.
 typedef std::map<double, VtValue> SdfTimeSampleMap;
 
@@ -454,6 +451,11 @@ SDF_API
 std::ostream & operator<<( std::ostream &out,
                            const SdfRelocatesMap &reloMap );
 
+/// Writes the string representation of \c SdfRelocates to \a out.
+SDF_API 
+std::ostream & operator<<( std::ostream &out,
+                           const SdfRelocates &relocates );
+
 /// Writes the string representation of \c SdfTimeSampleMap to \a out.
 SDF_API 
 std::ostream & operator<<( std::ostream &out,
